# -*- encoding: utf-8 -*-
# __author__ = jeff@openerp.cn
# __thanks__ = [oldrev@gmail.com, popkar77@gmail.com]
##############################################################################
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

import time
import pooler
from report import report_sxw
from tools.translate import _

#Step: Accouts selection
_ACCOUNT_FORM = u'''<?xml version="1.0"?>
<form string="Select accounts to print">
    <field name="accounts" colspan="4" mode="tree" />
    <newline/>
</form>'''

_ACCOUNT_FIELDS = {
    'accounts': {'string':'Accounts', 'type':'many2one', \
                 'relation':'account.account', 'required':True},
}


#Step: Select company, from period and to period
#      product for stock ledger, partner for three columns ledger

_PERIOD_FORM = '''<?xml version="1.0"?>
<form string="选择期间">
    <field name="company_id" />
    <newline/>
    <field name="period_form"/>
    <field name="period_to"/>
    <newline/>
    <field name="product" />
    <newline/>
    <field name="partner" />
    <newline/>
</form>'''


_PERIOD_FIELDS = {
    'company_id': {'string': 'Company', 'type': 'many2one', 'relation': 'res.company', 'required': True},
    'period_form':  {'string': 'From Period', 'type': 'many2one', 'relation': 'account.period', 'required': True},
    'period_to':  {'string': 'To Period', 'type': 'many2one', 'relation': 'account.period', 'required': True},
    'product': {'string':'Products','type':'many2one','relation':'product.product'},
    'partner': {'string':'Partners','type':'many2one','relation':'res.partner'},
}


def _check_path(self, cr, uid, data, context):
#Check if report is trigered on accouns form 
    if data['model'] == 'account.account':
        return 'checktype'
    else:
        return 'account_selection'

def _check(self, cr, uid, data, context):
    """
检查科目类型：
1.科目1002、1001结尾的且外币字段不为空打印“外币日记账”,外币字段为空就打印“现金日记账”
2.科目不是1002、1001结尾的，且有选择产品的打印“数量单位日记账”
3.其他“打印三栏式日记账”
    """
    new_ids = None
    if (data['model'] == 'account.account'):
        new_ids = data['ids'][0]
    else:
        new_ids = data['form']['accounts']
    account = pooler.get_pool(cr.dbname).get('account.account').browse(cr, uid, new_ids, context=context)
    if(account.code[0:4] == '1002' or account.code[0:4] == '1001'):
        if(account.currency_id):
            return 'currency_cash_journal'
        else:
            return 'cash_journal'
    elif data['form'].get('product',''):
        return 'stock_ledger'
    else:
        return 'threecolumns_ledger'


class WizardReport(wizard.interface):

    def _get_defaults(self, cr, uid, data, context={}):
        user = pooler.get_pool(cr.dbname).get('res.users').browse(cr, uid, uid, context=context)
        if user.company_id:
            company_id = user.company_id.id
        else:
            company_id = pooler.get_pool(cr.dbname).get('res.company').search(cr, uid, [('parent_id', '=', False)])[0]
        data['form']['company_id'] = company_id
        data['form']['report_type'] = 'threecolumns_ledger'
        #获取期间的开始结束时间
        ids = pooler.get_pool(cr.dbname).get('account.period').find(cr, uid, context=context)
        fiscalyear_id = pooler.get_pool(cr.dbname).get('account.period').browse(cr, uid, ids[0]).fiscalyear_id
        cr.execute(("SELECT date_start ,fiscalyear_id,id "\
                    "FROM account_period "\
                    "WHERE fiscalyear_id='%s' "\
                    "ORDER BY date_start asc ")% (int(fiscalyear_id)))
        res = cr.dictfetchall()
        data['form']['period_to'] = ids[0]
        data['form']['period_form'] = res[0]['id']
        data['form']['context'] = context
        return data['form']

    states = {
        'init': {
            'actions': [],
            # if triger from account list, input period
            # or select accounts first
            'result': {'type':'choice','next_state':_check_path}
        },
        'account_selection': {
            'actions': [],
            # select accounts
            'result': {'type':'form', 'arch':_ACCOUNT_FORM,'fields':_ACCOUNT_FIELDS, 
                'state':[('end',u'取消','gtk-cancel'),('checktype',u'下一步 >','gtk-go-forward')]}
        },
        'checktype': {
            'actions': [_get_defaults],
            # input period
            'result': {'type':'form', 'arch':_PERIOD_FORM, 'fields':_PERIOD_FIELDS, 
                'state':[('end',u'取消','gtk-cancel'),('checkreport',u'打印','gtk-print')]}
        },
        'checkreport': {
            'actions': [],
            # select the right detail ledger format for current account 
            'result': {'type':'choice','next_state':_check}
        },

        'cash_journal': {
        #现金日记账
            'actions': [],
            'result': {'type':'print', 'report':'account.cash_journal', 'state':'end'}
        },

        'currency_cash_journal': {
        #外币日记账
            'actions': [],
            'result': {'type':'print', 'report':'account.currency_cash_journal', 'state':'end'}
        },

        'threecolumns_ledger': {
        #三栏式明细账
            'actions': [],
            'result': {'type':'print', 'report':'account.threecolumns_ledger', 'state':'end'}
        },
        'stock_ledger': {
        #数量金额明细账
            'actions': [],
            'result': {'type':'print', 'report':'account.stock_ledger', 'state':'end'}
        },
    }

WizardReport('account.detail_ledger')

